@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2004  Thomas Bopp, Thorsten Hampel, Ludger Merkens
+/* Copyright (C) 2000-2005  Thomas Bopp, Thorsten Hampel, Ludger Merkens
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  * 
- * $Id: attributes.h,v 1.1.1.1 2005/09/21 14:22:14 exodusd Exp $
+ * $Id: attributes.h,v 1.1.1.1 2006/03/27 12:40:10 exodusd Exp $
  */
 #ifndef _ATTRIBUTES_H
 #define _ATTRIBUTES_H
@@ -42,6 +42,7 @@
 #define OBJ_TEMP                  "OBJ_TEMP"
 #define OBJ_ANNO_MESSAGE_IDS      "OBJ_ANNO_MESSAGE_IDS"
 #define OBJ_ANNO_MISSING_IDS      "OBJ_ANNO_MISSING_IDS"
+#define OBJ_ONTHOLOGY             "OBJ_ONTHOLOGY"
 
 #define DOC_TYPE                  "DOC_TYPE"
 #define DOC_MIME_TYPE             "DOC_MIME_TYPE"
@@ -64,6 +65,7 @@
 #define DOC_VERSION               "DOC_VERSION"
 #define DOCLPC_INSTANCETIME       "DOCLPC_INSTANCETIME"
 
+
 #define CONT_SIZE_X               "CONT_SIZE_X"
 #define CONT_SIZE_Y               "CONT_SIZE_Y"
 #define CONT_SIZE_Z               "CONT_SIZE_Z"
@@ -71,6 +73,7 @@
 #define CONT_MONITOR              "CONT_MONITOR"
 #define CONT_LAST_MODIFIED        "CONT_LAST_MODIFIED"
 #define CONT_CONTENT_SVG          "CONT_CONTENT_SVG"
+#define CONT_WSDL                 "CONT_WSDL"
 
 #define GROUP_MEMBERSHIP_REQS     "GROUP_MEMBERSHIP_REQS"
 #define GROUP_EXITS               "GROUP_EXITS"
@@ -105,6 +108,7 @@
 #define USER_PHONE                "USER_PHONE"
 #define USER_FAX                  "USER_FAX"
 #define USER_WIKI_TRAIL           "USER_WIKI_TRAIL"
+#define USER_MONITOR              "USER_MONITOR"
 
 #define GATE_REMOTE_SERVER        "GATE_REMOTE_SERVER"
 #define GATE_REMOTE_OBJ           "GATE_REMOTE_OBJ"
@@ -179,6 +183,8 @@
 #define DRAWING_CIRCLE             6
 #define DRAWING_TEXT               7
 
+#define SPM_FILES                 "SPM_FILES"
+#define SPM_MODULES               "SPM_MODULES"
 
 
 
