@@ -14,7 +14,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  * 
- * $Id: database.h,v 1.1.1.1 2005/09/21 14:22:14 exodusd Exp $
+ * $Id: database.h,v 1.1.1.1 2006/03/27 12:40:10 exodusd Exp $
  */
 
 #ifndef _DATABASE_H
@@ -61,9 +61,11 @@
 #define PSTAT_DISK                0
 #define PSTAT_SAVE_OK             1
 #define PSTAT_SAVE_PENDING        2
+#define PSTAT_DELETED             3
 
-#define PSTAT_NAMES ({ "deleted", "unserialize failed", "compile failed", \
-"on disk", "Ok", "save pending" })
+
+#define PSTAT_NAMES ({ "deletion failed", "unserialize failed","compile failed", \
+"on disk", "Ok", "save pending", "deleted" })
 
 #define STORE_GROUP     "group"
 #define STORE_ATTRIB    "attrib"
